@@ -30,7 +30,7 @@ class ErrorInfo(Error):
 
     name = "use-pathlib-is-funcs"
     code = 146
-    categories = ["pathlib"]
+    categories = ("pathlib",)
 
 
 PATH_TO_PATHLIB_NAMES = {
