@@ -25,7 +25,7 @@ class ErrorInfo(Error):
     usually is the result of not realizing a type is already the type you want,
     or artifacts of some debugging code. One example of where this might be
     intentional is when using container types like `dict` or `list`, which
-    will create a shadow copy. If that is the case, it might be preferable
+    will create a shallow copy. If that is the case, it might be preferable
     to use `.copy()` instead, since it makes it more explicit that a copy
     is taking place.
 
@@ -54,7 +54,7 @@ class ErrorInfo(Error):
 
     name = "no-redundant-cast"
     code = 123
-    categories = ["readability"]
+    categories = ("readability",)
 
 
 FUNC_NAMES = {
@@ -67,6 +67,7 @@ FUNC_NAMES = {
     "builtins.list": (ListExpr, "x.copy()"),
     "builtins.str": (StrExpr, "x"),
     "builtins.tuple": (TupleExpr, "x"),
+    "tuple[]": (TupleExpr, "x"),
 }
 
 
@@ -96,7 +97,10 @@ def check(node: CallExpr, errors: list[Error]) -> None:
                 match arg:
                     case NameExpr(node=Var(type=ty)) if (
                         str(ty).startswith(fullname)
-                        or (str(ty).startswith("Tuple") and name == "tuple")
+                        or (
+                            str(ty).lower().startswith("tuple[")
+                            and name == "tuple"
+                        )
                     ):
                         pass
 
